@@ -1,6 +1,6 @@
 package Catmandu::PICA;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 1;
 __END__
@@ -13,7 +13,7 @@ Catmandu::PICA - Catmandu modules for working with PICA+ data
 
 =begin markdown
 
-[![Unix Build Status](https://travis-ci.org/gbv/Catmandu-PICA.svg)](https://travis-ci.org/gbv/Catmandu-PICA)
+[![Linux build status](https://github.com/gbv/Catmandu-PICA/actions/workflows/linux.yml/badge.svg)](https://github.com/gbv/Catmandu-PICA/actions/workflows/linux.yml)
 [![Windows Build status](https://ci.appveyor.com/api/projects/status/myyyxpobr8kn6aby?svg=true)](https://ci.appveyor.com/project/nichtich/catmandu-pica)
 [![Coverage Status](https://coveralls.io/repos/gbv/Catmandu-PICA/badge.svg?branch=main)](https://coveralls.io/r/gbv/Catmandu-PICA?branch=main)
 [![Kwalitee Score](http://cpants.cpanauthors.org/dist/Catmandu-PICA.png)](http://cpants.cpanauthors.org/dist/Catmandu-PICA)
@@ -37,14 +37,24 @@ introduction into Catmandu.
 
 =item * L<Catmandu::Exporter::PICA>
 
+=item * L<Catmandu::Fix::pica_map>
+
+=item * L<Catmandu::Fix::pica_remove>
+
+=item * L<Catmandu::Fix::pica_keep>
+
+=item * L<Catmandu::Fix::pica_tag>
+
+=item * L<Catmandu::Fix::pica_occurrence>
+
 =item * L<Catmandu::Fix::Bind::pica_each>
 
+=item * L<Catmandu::Fix::Bind::pica_diff>
+
 =item * L<Catmandu::Fix::Condition::pica_match>
 
 =item * L<Catmandu::Fix::pica_add>
 
-=item * L<Catmandu::Fix::pica_map>
-
 =item * L<Catmandu::Fix::pica_set>
 
 =item * L<Catmandu::Importer::PICA>
